Module: Kayvee::Clients::KeyValueStoreClient::InstanceMethods

Defined in:
lib/kayvee/clients/key_value_store_client.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#optionsObject (readonly)

Returns the value of attribute options.



20
21
22
# File 'lib/kayvee/clients/key_value_store_client.rb', line 20

def options
  @options
end

Instance Method Details

#read(path) ⇒ String\nil

Returns the read string or nil if key does not exist.

Parameters:

  • path (String)

    the path to read

Returns:

  • (String\nil)

    the read string or nil if key does not exist

Raises:



32
33
34
# File 'lib/kayvee/clients/key_value_store_client.rb', line 32

def read(path)
  raise InterfaceNotImplementedError.new
end

#url(path) ⇒ String

Returns the url.

Parameters:

  • path (String)

    the path to convert to a url

Returns:

Raises:



25
26
27
# File 'lib/kayvee/clients/key_value_store_client.rb', line 25

def url(path)
  raise InterfaceNotImplementedError.new
end

#write(path, value) ⇒ Key

Returns the key modified.

Parameters:

  • path (String)

    the path to read

  • value (String)

    the value to set

Returns:

  • (Key)

    the key modified

Raises:



40
41
42
# File 'lib/kayvee/clients/key_value_store_client.rb', line 40

def write(path, value)
  raise InterfaceNotImplementedError.new
end

#write_io(path, io) ⇒ Object



44
45
46
# File 'lib/kayvee/clients/key_value_store_client.rb', line 44

def write_io(path, io)
  raise InterfaceNotImplementedError.new
end