Module: Kayvee::Clients::KeyValueStoreClient::InstanceMethods
- Defined in:
- lib/kayvee/clients/key_value_store_client.rb
Instance Attribute Summary collapse
-
#options ⇒ Object
readonly
Returns the value of attribute options.
Instance Method Summary collapse
-
#read(path) ⇒ String\nil
The read string or nil if key does not exist.
-
#url(path) ⇒ String
The url.
-
#write(path, value) ⇒ Key
The key modified.
- #write_io(path, io) ⇒ Object
Instance Attribute Details
#options ⇒ Object (readonly)
Returns the value of attribute options.
20 21 22 |
# File 'lib/kayvee/clients/key_value_store_client.rb', line 20 def @options end |
Instance Method Details
#read(path) ⇒ String\nil
Returns the read string or nil if key does not exist.
32 33 34 |
# File 'lib/kayvee/clients/key_value_store_client.rb', line 32 def read(path) raise InterfaceNotImplementedError.new end |
#url(path) ⇒ String
Returns the url.
25 26 27 |
# File 'lib/kayvee/clients/key_value_store_client.rb', line 25 def url(path) raise InterfaceNotImplementedError.new end |
#write(path, value) ⇒ Key
Returns the key modified.
40 41 42 |
# File 'lib/kayvee/clients/key_value_store_client.rb', line 40 def write(path, value) raise InterfaceNotImplementedError.new end |
#write_io(path, io) ⇒ Object
44 45 46 |
# File 'lib/kayvee/clients/key_value_store_client.rb', line 44 def write_io(path, io) raise InterfaceNotImplementedError.new end |